@@ -200,6 +200,8 @@ class Model:
             t += f'Images left: [{self.imageQueue.qsize()}] '
             t += f'Solves left: [{self.solveQueue.qsize()}] '
             self.log.error(t)
+            self.app.message.emit('Cancel build because of error', 2)
+            self.cancelBuild()
             return False
 
         self.log.debug('Processing astrometry result')
