@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 #
 # Licence APL2.0
 #
@@ -447,7 +447,7 @@ class SettDevice:
 
         :param driver:
         :param autoStart:
-        :return: success if a driver has ben started
+        :return: success if a driver has been started
         """
         if not driver:
             return False
